[llvm-commits] CVS: llvm/include/llvm/Target/TargetInstrInfo.h

Evan Cheng evan.cheng at apple.com
Wed Nov 1 15:14:14 PST 2006



Changes in directory llvm/include/llvm/Target:

TargetInstrInfo.h updated: 1.101 -> 1.102
---
Log message:

Rename

---
Diffs of the changes:  (+2 -2)

 TargetInstrInfo.h |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


Index: llvm/include/llvm/Target/TargetInstrInfo.h
diff -u llvm/include/llvm/Target/TargetInstrInfo.h:1.101 llvm/include/llvm/Target/TargetInstrInfo.h:1.102
--- llvm/include/llvm/Target/TargetInstrInfo.h:1.101	Wed Nov  1 16:59:52 2006
+++ llvm/include/llvm/Target/TargetInstrInfo.h	Wed Nov  1 17:14:00 2006
@@ -240,9 +240,9 @@
     return -1;
   }
 
   /// getTiedToSrcOperand - Returns the operand that is tied to the specified
   /// dest operand. Returns -1 if there isn't one.
-  int getTiedToSrcOperand(MachineOpCode Opcode, unsigned OpNum) const;
+  int findTiedToSrcOperand(MachineOpCode Opcode, unsigned OpNum) const;
 
   /// getDWARF_LABELOpcode - Return the opcode of the target's DWARF_LABEL
   /// instruction if it has one.  This is used by codegen passes that update
@@ -240,9 +240,9 @@
   }
 
-  /// getTiedToSrcOperand - Returns the operand that is tied to the specified
+  /// findTiedToSrcOperand - Returns the operand that is tied to the specified
   /// dest operand. Returns -1 if there isn't one.






More information about the llvm-commits mailing list